/***** interface.c ************************************************
 * Description: Routine for gathering arguments from the command
 *              line.
 * Author: Bernhard Haubold, haubold@evolbio.mpg.de
 * Date: Sun Jun 20 13:12:10 2004.
 *****************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include "interface.h"
#include "eprintf.h"

Args *args;

Args *getArgs(int argc, char *argv[]){
  int c;
  char *optString = "hvlnp:P:";

  args = (Args *)emalloc(sizeof(Args));
  args->p = NULL;
  args->P = NULL;
  args->l = 0;
  args->n = 0;
  args->h = 0;
  args->v = 0;
  args->e = 0;

  c = getopt(argc, argv, optString);
  while(c != -1){
    switch(c){
    case 'n':                           /* naive algorithm? */
      args->n = 1;
      break;
    case 'p':
      args->p = optarg;
      break;
    case 'P':
      args->P = optarg;
      break;
    case 'l':
      args->l = 1;
      break;
    case '?':                           /* fall-through is intentional */
    case 'h':                           /* print help */
      args->h = 1;
      break;
    case 'v':                           /* print version */
      args->v = 1;
      break;
    default:
      printf("# unknown argument: %c\n",c);
      args->e = 1;
      return args;
    }
    c = getopt(argc, argv, optString);
  }
  args->inputFiles = argv + optind;
  args->numInputFiles = argc - optind;
  if(args->p == NULL && args->P == NULL && !args->h && !args->v){
    printf("ERROR: Please enter a pattern using the options -p or -P.\n");
    args->e = 1;
  }
  return args;
}


void printUsage(char *version){
  printf("Usage: %s [options] [inputFiles]\n",progname());
  printf("Exact matching using naive algorithm.\n");
  printf("Example: naiveMatcher -p ACCGT input.fasta\n");
  printf("Options:\n");
  printf("\t-p <STRING> pattern to be searched for\n");
  printf("\t-P <FILE> file containing pattern to be searched for; either -p or -P are mandatory\n");
  printf("\t[-h print this help message and exit]\n");
  printf("\t[-v print program information and exit]\n");
  exit(0);
}

void printSplash(char *version){
  printf("%s %s\n",progname(),version);
  printf("Written by Bernhard Haubold.\n");
  printf("Distributed under the GNU General Public License.\n");
  printf("Please send bug reports to haubold@evolbio.mpg.de\n");
  exit(0);
}
